/*

Copyright (c) 2012-2014 RedBearLab

Permission is hereby granted, free of charge, to any person obtaining a copy of this software 
and associated documentation files (the "Software"), to deal in the Software without restriction, 
including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, 
and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, 
subject to the following conditions:
The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, 
INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE 
FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*/

#include "Servo.h"

Servo::Servo(PinName aServoPin, PinName aTRPin): servoPin(aServoPin), _tr(aTRPin)
{
    _tr = 1.0f;    
    _servo = new PwmOut(servoPin);        
    _servo->period_ms(20);
    _servo->pulsewidth_us(convert(MIDDLE_DEGREE_OF_SERVO));    
    wait(2.0);
    currentDegree = MIDDLE_DEGREE_OF_SERVO;    
    _tr = 0.0f;    
    *_servo = 0.0f;
}

Servo::~Servo(void)
{
}

void Servo::write(unsigned char aNewDegree)
{
    _tr = 1.0f;        
    _servo->period_ms(20);
    _servo->pulsewidth_us(convert(aNewDegree));
    wait(abs((int)aNewDegree-(int)currentDegree)*0.01);
    currentDegree = aNewDegree;     
    _tr = 0.0f;   
    *_servo = 0.0f;
}

unsigned int Servo::convert(unsigned char degree)
{
    // 0~180 degree correspond to 500~2500
    return degree * 11 + 500;
}
